@@ -6,8 +6,8 @@ from lazyearth.mainfile import objearth
 from lazyearth.mainfile import water
 from lazyearth.mainfile import imagedataset
 
-deving_by = 'tul kedsaro'
-
-__version__ = '1.0.16'
+__author__  = 'tul kedsaro'
+__email__   = 'Tun.k@ku.th'
+__version__ = '1.0.17'
 print(f'Lazyearth version : {__version__} Krub')
 
