@@ -244,13 +244,13 @@ class objearth():
         nir = xarray.where(self.DataArray.nir==-9999,numpy.nan,self.DataArray.nir)
         evi1 = (nir-red)/(nir+6*red-7.5*blue+1).to_numpy()
         evi3 = numpy.clip(evi1,-1,1)
-        im_ratio = evi3.shape[1]/evi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(evi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
+        # im_ratio = evi3.shape[1]/evi3.shape[0]
+        # plt.figure(figsize=(8,8))
+        # plt.xticks([]), plt.yticks([])
+        # plt.imshow(evi3,cmap='viridis')
+        # plt.clim(-1,1)
+        # plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        # plt.show()
         return evi3
         
 
@@ -265,7 +265,7 @@ class objearth():
         nir = xarray.where(self.DataArray.nir==-9999,numpy.nan,self.DataArray.nir)
         ndmi1 = (nir-swir)/(nir+swir).to_numpy()
         ndmi3 = numpy.clip(ndmi1,-1,1)
-        im_ratio = ndmi3.shape[1]/ndmi3.shape[0]
+        # im_ratio = ndmi3.shape[1]/ndmi3.shape[0]
         return ndmi3
 
     def BSI(self,DataArray):
@@ -280,12 +280,12 @@ class objearth():
         bsi1 = (nir+green)/(green-nir).to_numpy()
         bsi3 = numpy.clip(bsi1,-1,1)
         im_ratio = bsi3.shape[1]/bsi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(bsi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
+        # plt.figure(figsize=(8,8))
+        # plt.xticks([]), plt.yticks([])
+        # plt.imshow(bsi3,cmap='viridis')
+        # plt.clim(-1,1)
+        # plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        # plt.show()
         return bsi3
 
     def NDWI(self,DataArray):
@@ -300,12 +300,12 @@ class objearth():
         ndwi1 = (nir-swir)/(nir+swir).to_numpy()
         ndwi3 = numpy.clip(ndwi1,-1,1)
         im_ratio = ndwi3.shape[1]/ndwi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(ndwi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
+        # plt.figure(figsize=(8,8))
+        # plt.xticks([]), plt.yticks([])
+        # plt.imshow(ndwi3,cmap='viridis')
+        # plt.clim(-1,1)
+        # plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        # plt.show()
         return ndwi3
 
     def NMDI(self,DataArray):
@@ -321,12 +321,12 @@ class objearth():
         nmdi1 = (nir-(swir1-swir2))/(nir-(swir1+swir2)).to_numpy()
         nmdi3 = numpy.clip(nmdi1,-1,1)
         im_ratio = nmdi3.shape[1]/nmdi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(nmdi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
+        # plt.figure(figsize=(8,8))
+        # plt.xticks([]), plt.yticks([])
+        # plt.imshow(nmdi3,cmap='viridis')
+        # plt.clim(-1,1)
+        # plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        # plt.show()
         return nmdi3
 
     def NDDI(self,DataArray):
@@ -344,12 +344,12 @@ class objearth():
         nddi1 = (ndvi-ndwi)/(ndvi+ndwi).to_numpy() 
         nddi3 = numpy.clip(nddi1,-1,1)
         im_ratio = nddi3.shape[1]/nddi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(nddi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
+        # plt.figure(figsize=(8,8))
+        # plt.xticks([]), plt.yticks([])
+        # plt.imshow(nddi3,cmap='viridis')
+        # plt.clim(-1,1)
+        # plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        # plt.show()
         return nddi3
 
     def genimg(size=[2,2],range=[-1,1],nan=0,inf=0):
@@ -1407,17 +1407,41 @@ class water:
 
 
 class imagedataset(objearth,water):
+    def __new__(cls,image_dataset):
+        if (isinstance(image_dataset,xarray.Dataset) and 'time' in image_dataset.dims and image_dataset.dims['time']>1):
+            instance = super().__new__(cls)
+            print('Creating imageDataset object ...')
+            return instance
+        else:
+            raise TypeError("image_dataset have to be xarray.Dataset and have more that 1 time")
     def __init__(self,image_dataset):
+        """
+        This class operator with Dataset
+        :param command : xarray.Dataset
+        """
         self.ids = image_dataset
+        print("Done.")
+    #TODO
+    def __str__(self):
+        pass
     def detail(self):
         print(self.ids)
     def listtime(self):
-        output_list = []
+        """
+        list all time of data
+        Return: int
+        """
+        # output_list = []
         rnd = self.ids.dims['time']
         for i in range(rnd):
             t = self.ids.isel(time=i).time.values
             print(t)
     def operator(self,command):
+        """
+        This function use for imagedataset operator with objearth function
+        :param command : objearth function
+        :return        : output_dict (specail type)
+        """
         r = self.ids.dims['time']
         output_dict = {}
         for i in range(r):
@@ -1429,6 +1453,16 @@ class imagedataset(objearth,water):
                 val = super().NDVI(eds)
             elif command == 'NDMI':
                 val = super().NDMI(eds)
+            elif command == 'BSI':
+                val = super().BSI(eds)
+            elif command == 'EVI':
+                val = super().EVI(eds)
+            elif command == 'NDDI':
+                val = super().NDDI(eds)
+            elif command == 'NDWI':
+                val = super().NDWI(eds)
+            elif command == 'NMDI':
+                val = super().NMDI(eds)
             elif command == 'waterdetect':
                 val = water(eds).waterdetect()
             elif command == 'waterquality':
